@@ -1,21 +1,21 @@
-/*
- *Copyright (C) 2004-2007 Qball Cow <Qball@qballcow.nl>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
+/* libmpd (high level libmpdclient library)
+ * Copyright (C) 2004-2009 Qball Cow <qball@sarine.nl>
+ * Project homepage: http://gmpcwiki.sarine.nl/
+ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -63,7 +63,7 @@ long long mpd_playlist_get_playlist_id(MpdObj *mi)
 	}
 	return mi->status->playlist;
 }
-int mpd_playlist_add(MpdObj *mi, char *path)
+int mpd_playlist_add(MpdObj *mi,const char *path)
 {
 	int retv = mpd_playlist_queue_add(mi, path);
 	if(retv != MPD_OK) return retv;
@@ -184,6 +184,56 @@ mpd_Song * mpd_playlist_get_song_from_pos(MpdObj *mi, int songpos)
 	return song;
 }
 
+MpdData * mpd_playlist_get_song_from_pos_range(MpdObj *mi, int start, int stop)
+{
+    MpdData *data = NULL;
+    int i;
+	mpd_InfoEntity *ent = NULL;
+	if(!mpd_check_connected(mi))
+	{
+		debug_printf(DEBUG_ERROR, "Not Connected\n");
+		return NULL;
+	}
+	if(mpd_status_check(mi) != MPD_OK)
+	{
+		debug_printf(DEBUG_ERROR,"Failed grabbing status\n");
+		return NULL;
+	}
+
+	if(mpd_lock_conn(mi))
+	{
+		return NULL;
+	}
+    /* Don't check outside playlist length */
+    if(!(stop < mi->status->playlistLength)) {
+        stop = mi->status->playlistLength -1;
+    }
+    mpd_sendCommandListBegin(mi->connection);
+    for(i=start; i <= stop; i++){
+        mpd_sendPlaylistInfoCommand(mi->connection, i);
+    }
+	mpd_sendCommandListEnd(mi->connection);
+	while (( ent = mpd_getNextInfoEntity(mi->connection)) != NULL)
+	{
+		if(ent->type == MPD_INFO_ENTITY_TYPE_SONG)
+		{
+			data = mpd_new_data_struct_append(data);
+			data->type = MPD_DATA_TYPE_SONG;
+			data->song = ent->info.song;
+			ent->info.song = NULL;
+		}
+		mpd_freeInfoEntity(ent);
+	}
+	mpd_finishCommand(mi->connection);
+
+	if(mpd_unlock_conn(mi))
+	{
+		/*TODO free entity. for now this can never happen */
+		return NULL;
+	}
+    return data;
+}
+
 mpd_Song * mpd_playlist_get_current_song(MpdObj *mi)
 {
 	if(!mpd_check_connected(mi))
@@ -416,7 +466,7 @@ MpdData * mpd_playlist_get_changes_posid(MpdObj *mi,int old_playlist_id)
 	return mpd_data_get_first(data);
 }
 
-int mpd_playlist_queue_add(MpdObj *mi,char *path)
+int mpd_playlist_queue_add(MpdObj *mi,const char *path)
 {
 	if(!mpd_check_connected(mi))
 	{
@@ -449,7 +499,7 @@ int mpd_playlist_queue_add(MpdObj *mi,char *path)
 	return MPD_OK;
 }
 
-int mpd_playlist_queue_load(MpdObj *mi,char *path)
+int mpd_playlist_queue_load(MpdObj *mi,const char *path)
 {
 	if(!mpd_check_connected(mi))
 	{
@@ -600,7 +650,7 @@ int mpd_playlist_queue_delete_pos(MpdObj *mi,int songpos)
 	return MPD_OK;
 }
 
-int mpd_playlist_add_get_id(MpdObj *mi, char *path)
+int mpd_playlist_add_get_id(MpdObj *mi,const char *path)
 {
 	int songid = -1;
 	if(mi == NULL || path == NULL)
