@@ -1,21 +1,21 @@
-/*
- *Copyright (C) 2004-2007 Qball Cow <Qball@qballcow.nl>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
+/* libmpd (high level libmpdclient library)
+ * Copyright (C) 2004-2009 Qball Cow <qball@sarine.nl>
+ * Project homepage: http://gmpcwiki.sarine.nl/
+ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,7 +36,7 @@ int mpd_status_queue_update(MpdObj *mi)
 
 	if(!mpd_check_connected(mi))
 	{
-		debug_printf(DEBUG_INFO,"Where not connected\n");
+		debug_printf(DEBUG_INFO,"not connected\n");
 		return MPD_NOT_CONNECTED;
 	}
 	if(mi->status != NULL)
@@ -53,7 +53,7 @@ int mpd_status_update(MpdObj *mi)
 	ChangedStatusType what_changed=0;
 	if(!mpd_check_connected(mi))
 	{
-		debug_printf(DEBUG_INFO,"Where not connected\n");
+		debug_printf(DEBUG_INFO,"not connected\n");
 		return MPD_NOT_CONNECTED;
 	}
 	if(mpd_lock_conn(mi))
@@ -271,16 +271,30 @@ int mpd_status_update(MpdObj *mi)
         }
     }else {
         char *name;
+        int update_stats = 0;
         mpd_sendGetEventsCommand(mi->connection);    
         while((name = mpd_getNextEvent(mi->connection))){
             if(strcmp(name, "output") == 0){
                 what_changed |= MPD_CST_OUTPUT;
+            }else if (strcmp(name, "database") == 0) {
+                if((what_changed&MPD_CST_DATABASE) == 0)
+                {
+                    update_stats = 1;
+                }
+                what_changed |= MPD_CST_DATABASE;
             }else if (strcmp(name, "stored_playlist")==0) {
                 what_changed |= MPD_CST_STORED_PLAYLIST;
+            }else if (strcmp(name, "tag") == 0) {
+                what_changed |= MPD_CST_PLAYLIST;
+            }else if (strcmp (name, "sticker") == 0) {
+                what_changed |= MPD_CST_STICKER;
             }
             free(name);
        }
        mpd_finishCommand(mi->connection);
+       if(update_stats) {
+           mpd_stats_update_real(mi, &what_changed);
+       }
     }
 
   
@@ -511,9 +525,13 @@ char * mpd_status_get_mpd_error(MpdObj *mi)
     return NULL;
 }
 
-/* TODO: error checking might be nice? */
 int mpd_status_db_is_updating(MpdObj *mi)
 {
+	if(!mpd_check_connected(mi))
+	{
+		debug_printf(DEBUG_WARNING, "mpd_check_connected failed.\n");
+		return FALSE;
+	}
 	return mi->CurrentState.updatingDb;
 }
 
@@ -638,7 +656,7 @@ int mpd_stats_update_real(MpdObj *mi, ChangedStatusType* what_changed)
 
 	if(!mpd_check_connected(mi))
 	{
-		debug_printf(DEBUG_INFO,"Where not connected\n");
+		debug_printf(DEBUG_INFO,"not connected\n");
 		return MPD_NOT_CONNECTED;
 	}
 	if(mpd_lock_conn(mi))
