@@ -1,21 +1,21 @@
-/*
- *Copyright (C) 2004-2007 Qball Cow <Qball@qballcow.nl>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
+/* libmpd (high level libmpdclient library)
+ * Copyright (C) 2004-2009 Qball Cow <qball@sarine.nl>
+ * Project homepage: http://gmpcwiki.sarine.nl/
+ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -150,6 +150,9 @@ static MpdObj * mpd_create()
     /* outputs */
     mi->num_outputs = 0;
     mi->output_states = NULL;
+    /* set 0 */ 
+    memset((mi->supported_tags), 0,sizeof(mi->supported_tags));
+
     mi->has_idle = 0;
 	/* commands */
 	mi->commands = NULL;
@@ -355,7 +358,7 @@ int mpd_set_hostname(MpdObj *mi, char *hostname)
 	return MPD_OK;
 }
 
-int mpd_set_password(MpdObj *mi, char *password)
+int mpd_set_password(MpdObj *mi, const char *password)
 {
 	if(mi == NULL)
 	{
@@ -581,6 +584,10 @@ int mpd_disconnect(MpdObj *mi)
     if(mi->output_states)
         g_free(mi->output_states);
     mi->output_states = NULL;
+
+    /* set 0 */ 
+    memset((mi->supported_tags), 0,sizeof(mi->supported_tags));
+
     mi->has_idle = 0;
 	
 	memcpy(&(mi->OldState), &(mi->CurrentState) , sizeof(MpdServerState));
@@ -680,13 +687,32 @@ int mpd_connect_real(MpdObj *mi,mpd_Connection *connection)
     if(retv != MPD_OK)
         return retv;
 */
+
+    retv = mpd_server_update_outputs(mi);
+    /** update the supported tags */
+    {
+        int i;
+        char **retv = mpd_server_get_tag_types(mi);
+        if(retv){
+            for(i=0;i<MPD_TAG_ITEM_ANY;i++)
+            {
+                int j=0;
+                for(j=0;retv[j] && strcasecmp(retv[j],mpdTagItemKeys[i]); j++);
+                if(retv[j]) mi->supported_tags[i] = TRUE;
+                else mi->supported_tags[i] = FALSE;
+            }
+            g_strfreev(retv);
+        }
+        /* also always true */ 
+        mi->supported_tags[MPD_TAG_ITEM_FILENAME] = TRUE;
+        mi->supported_tags[MPD_TAG_ITEM_ANY] = TRUE;
+    }
     debug_printf(DEBUG_INFO,  "Propagating connection changed");
 
     if(mi->the_connection_changed_callback != NULL)
 	{
 		mi->the_connection_changed_callback( mi, TRUE, mi->the_connection_changed_signal_userdata );
 	}
-    retv = mpd_server_update_outputs(mi);
     /*
     if(retv != MPD_OK)
         return retv;
@@ -1222,3 +1248,12 @@ int mpd_server_has_idle(MpdObj *mi)
 {
     return mi->has_idle;
 }
+
+int mpd_server_tag_supported(MpdObj *mi, int tag)
+{
+    if(!mi) return FALSE;
+    if(tag < 0 || tag >= MPD_TAG_NUM_OF_ITEM_TYPES) {
+        return FALSE;
+    }
+    return mi->supported_tags[tag];
+}
