@@ -270,6 +270,7 @@ char * mpdTagItemKeys[MPD_TAG_NUM_OF_ITEM_TYPES] =
 	"Comment",
 	"Disc",
 	"Filename",
+    "AlbumArtist",
 	"Any"
 };
 
@@ -496,11 +497,11 @@ void mpd_closeConnection(mpd_Connection * connection) {
 	WSACleanup();
 }
 
-static void mpd_executeCommand(mpd_Connection * connection, char * command) {
+static void mpd_executeCommand(mpd_Connection * connection,const char * command) {
 	int ret;
 	struct timeval tv;
 	fd_set fds;
-	char * commandPtr = command;
+	const char * commandPtr = command;
 	int commandLen = strlen(command);
 
 	if(!connection->doneProcessing && !connection->commandList) {
@@ -990,6 +991,7 @@ static void mpd_initSong(mpd_Song * song) {
 	song->performer = NULL;
 	song->disc = NULL;
 	song->comment = NULL;
+    song->albumartist = NULL;
 
 	song->time = MPD_SONG_NO_TIME;
 	song->pos = MPD_SONG_NO_NUM;
@@ -1009,6 +1011,7 @@ static void mpd_finishSong(mpd_Song * song) {
 	if(song->performer) free(song->performer);
 	if(song->disc) free(song->disc);
 	if(song->comment) free(song->comment);
+    if(song->albumartist) free(song->albumartist);
 }
 
 mpd_Song * mpd_newSong(void) {
@@ -1024,7 +1027,7 @@ void mpd_freeSong(mpd_Song * song) {
 	free(song);
 }
 
-mpd_Song * mpd_songDup(mpd_Song * song) {
+mpd_Song * mpd_songDup(const mpd_Song * song) {
 	mpd_Song * ret = mpd_newSong();
 
 	if(song->file) ret->file = strdup(song->file);
@@ -1039,6 +1042,7 @@ mpd_Song * mpd_songDup(mpd_Song * song) {
 	if(song->performer) ret->performer = strdup(song->performer);
 	if(song->disc) ret->disc = strdup(song->disc);
 	if(song->comment) ret->comment = strdup(song->comment);
+    if(song->albumartist) ret->albumartist = strdup(song->albumartist);
 	ret->time = song->time;
 	ret->pos = song->pos;
 	ret->id = song->id;
@@ -1139,7 +1143,7 @@ void mpd_freeInfoEntity(mpd_InfoEntity * entity) {
 	free(entity);
 }
 
-static void mpd_sendInfoCommand(mpd_Connection * connection, char * command) {
+static void mpd_sendInfoCommand(mpd_Connection * connection,const char * command) {
 	mpd_executeCommand(connection,command);
 }
 
@@ -1291,6 +1295,11 @@ mpd_InfoEntity * mpd_getNextInfoEntity(mpd_Connection * connection) {
 					strcmp(re->name, "Comment") == 0) {
 				entity->info.song->comment = strdup(re->value);
 			}
+
+			else if(!entity->info.song->albumartist &&
+					strcmp(re->name, "AlbumArtist") == 0) {
+				entity->info.song->albumartist = strdup(re->value);
+			}
 		}
 		else if(entity->type == MPD_INFO_ENTITY_TYPE_DIRECTORY) {
 		}
@@ -1635,7 +1644,7 @@ void mpd_sendSeekIdCommand(mpd_Connection * connection, int id, int time) {
 	free(string);
 }
 
-void mpd_sendUpdateCommand(mpd_Connection * connection, char * path) {
+void mpd_sendUpdateCommand(mpd_Connection * connection,const char * path) {
 	char * sPath = mpd_sanitizeArg(path);
 	int len = strlen("update")+2+strlen(sPath)+3;
 	char *string = malloc(len);
@@ -1983,7 +1992,7 @@ void mpd_commitSearch(mpd_Connection *connection)
  * List the content, with full metadata, of a stored playlist.
  *
  */
-void mpd_sendListPlaylistInfoCommand(mpd_Connection *connection, char *path)
+void mpd_sendListPlaylistInfoCommand(mpd_Connection *connection,const char *path)
 {
 	char *arg = mpd_sanitizeArg(path);
 	int len = strlen("listplaylistinfo")+2+strlen(arg)+3;
@@ -2001,7 +2010,7 @@ void mpd_sendListPlaylistInfoCommand(mpd_Connection *connection, char *path)
  * List the content of a stored playlist.
  *
  */
-void mpd_sendListPlaylistCommand(mpd_Connection *connection, char *path)
+void mpd_sendListPlaylistCommand(mpd_Connection *connection,const char *path)
 {
 	char *arg = mpd_sanitizeArg(path);
 	int len = strlen("listplaylist")+2+strlen(arg)+3;
@@ -2012,7 +2021,7 @@ void mpd_sendListPlaylistCommand(mpd_Connection *connection, char *path)
 	free(query);
 }
 
-void mpd_sendPlaylistClearCommand(mpd_Connection *connection, char *path)
+void mpd_sendPlaylistClearCommand(mpd_Connection *connection,const char *path)
 {
 	char *sPath = mpd_sanitizeArg(path);
 	int len = strlen("playlistclear")+2+strlen(sPath)+3;
@@ -2024,7 +2033,7 @@ void mpd_sendPlaylistClearCommand(mpd_Connection *connection, char *path)
 }
 
 void mpd_sendPlaylistAddCommand(mpd_Connection *connection,
-                                char *playlist, char *path)
+                                const char *playlist,const char *path)
 {
 	char *sPlaylist = mpd_sanitizeArg(playlist);
 	char *sPath = mpd_sanitizeArg(path);
@@ -2038,7 +2047,7 @@ void mpd_sendPlaylistAddCommand(mpd_Connection *connection,
 }
 
 void mpd_sendPlaylistMoveCommand(mpd_Connection *connection,
-                                 char *playlist, int from, int to)
+                                 const char *playlist, int from, int to)
 {
 	char *sPlaylist = mpd_sanitizeArg(playlist);
 	int len = strlen("playlistmove")+
@@ -2052,7 +2061,7 @@ void mpd_sendPlaylistMoveCommand(mpd_Connection *connection,
 }
 
 void mpd_sendPlaylistDeleteCommand(mpd_Connection *connection,
-                                   char *playlist, int pos)
+                                   const char *playlist, int pos)
 {
 	char *sPlaylist = mpd_sanitizeArg(playlist);
 	int len = strlen("playlistdelete")+2+strlen(sPlaylist)+3+INTLEN+3;
@@ -2080,3 +2089,36 @@ char * mpd_getNextEvent(mpd_Connection *connection)
 void mpd_sendListPlaylistsCommand(mpd_Connection * connection) {
     mpd_sendInfoCommand(connection, "listplaylists\n");
 }
+
+char * mpd_getNextSticker (mpd_Connection * connection)
+{
+	return mpd_getNextReturnElementNamed(connection, "sticker");
+}
+void  mpd_sendGetSongSticker(mpd_Connection *connection, const char *song_path, const char *sticker)
+{
+    char *sSong = mpd_sanitizeArg(song_path); 
+    char *sSticker = mpd_sanitizeArg(sticker); 
+    int len = strlen("sticker get song ")+strlen(sSong)+3+strlen(sSticker)+4;
+    char *string = malloc(len);
+    snprintf(string, len, "sticker get song \"%s\" \"%s\"\n", sSong, sSticker);
+    mpd_executeCommand(connection, string);
+    free(string);
+    free(sSong);
+    free(sSticker);
+}
+
+void mpd_sendSetSongSticker(mpd_Connection *connection, const char *song_path, const char *sticker, const char *value)
+{
+
+    char *sSong = mpd_sanitizeArg(song_path); 
+    char *sSticker = mpd_sanitizeArg(sticker); 
+    char *sValue = mpd_sanitizeArg(value);
+    int len = strlen("sticker set song ")+strlen(sSong)+3+strlen(sSticker)+3+strlen(sValue)+4;
+    char *string = malloc(len);
+    snprintf(string, len, "sticker set song \"%s\" \"%s\" \"%s\"\n", sSong, sSticker,sValue);
+    mpd_sendInfoCommand(connection, string);
+    free(string);
+    free(sSong);
+    free(sSticker);
+    free(sValue);
+}
